@@ -418,8 +418,8 @@
         this.getCssSelector = function getCssSelector(selector, scope, limit) {
             scope = scope || this.options.scope;
             limit = limit || 'BODY';
-            var elem = this.findOne(selector, scope);
-            if (!!elem) {
+            var elem = (selector instanceof Node) ? selector : this.findOne(selector, scope);
+            if (!!elem && elem.nodeName !== "#document") {
                 var str = "";
                 while (elem.nodeName.toUpperCase() !== limit.toUpperCase()) {
                     str = "> " + elem.nodeName + ':nth-child(' + ([].indexOf.call(elem.parentNode.children, elem) + 1) + ') ' + str;
@@ -427,7 +427,7 @@
                 }
                 return str.substring(2);
             }
-            return this.findOne(selector).nodeName;
+            return "";
         };
         
         /**
@@ -788,7 +788,7 @@
          */
         this.mouseEvent = function mouseEvent(type, selector, x, y) {
             var elem = this.findOne(selector);
-            if (!elem || ( !this.elementVisible(elem) && elem.nodeName.toUpperCase() !== "AREA")) {
+            if (!elem) {
                 this.log("mouseEvent(): Couldn't find any element matching '" +
                     selector + "' selector", "error");
                 return false;
@@ -1019,53 +1019,55 @@
             } catch (e) {
                 this.log("Unable to focus() input field " + field.getAttribute('name') + ": " + e, "warning");
             }
-
-            filter = String(field.getAttribute('type') ? field.getAttribute('type') : field.nodeName).toLowerCase();
-            switch (filter) {
-                case "checkbox":
-                case "radio":
-                    field.checked = value ? true : false;
-                    break;
-                case "file":
-                    throw {
-                        name: "FileUploadError",
-                        message: "File field must be filled using page.uploadFile",
-                        path: value,
-                        id: field.id || null
-                    };
-                    break;
-                case "select":
-                    if (field.multiple) {
-                        [].forEach.call(field.options, function(option) {
-                            option.selected = value.indexOf(option.value) !== -1;
-                        });
-                        // If the values can't be found, try search options text
-                        if (field.value === "") {
+            if (field.getAttribute('contenteditable')) {
+                field.textContent = value;
+            } else {
+                filter = String(field.getAttribute('type') ? field.getAttribute('type') : field.nodeName).toLowerCase();
+                switch (filter) {
+                    case "checkbox":
+                    case "radio":
+                        field.checked = value ? true : false;
+                        break;
+                    case "file":
+                        throw {
+                            name: "FileUploadError",
+                            message: "File field must be filled using page.uploadFile",
+                            path: value,
+                            id: field.id || null
+                        };
+                        break;
+                    case "select":
+                        if (field.multiple) {
                             [].forEach.call(field.options, function(option) {
-                                option.selected = value.indexOf(option.text) !== -1;
+                                option.selected = value.indexOf(option.value) !== -1;
                             });
-                        }
-                    } else {
-                        // PhantomJS 1.x.x can't handle setting value to ''
-                        if (value === "") {
-                            field.selectedIndex = -1;
+                            // If the values can't be found, try search options text
+                            if (field.value === "") {
+                                [].forEach.call(field.options, function(option) {
+                                    option.selected = value.indexOf(option.text) !== -1;
+                                });
+                            }
                         } else {
-                            field.value = value;
-                        }
+                            // PhantomJS 1.x.x can't handle setting value to ''
+                            if (value === "") {
+                                field.selectedIndex = -1;
+                            } else {
+                                field.value = value;
+                            }
 
-                        // If the value can't be found, try search options text
-                        if (field.value !== value) {
-                            [].some.call(field.options, function(option) {
-                                option.selected = value === option.text;
-                                return value === option.text;
-                            });
+                            // If the value can't be found, try search options text
+                            if (field.value !== value) {
+                                [].some.call(field.options, function(option) {
+                                    option.selected = value === option.text;
+                                    return value === option.text;
+                                });
+                            }
                         }
-                    }
-                    break;
-                default:
-                    field.value = value;
+                        break;
+                    default:
+                        field.value = value;
+                }
             }
-
             ['change', 'input'].forEach(function(name) {
                 var event = document.createEvent("HTMLEvents");
                 event.initEvent(name, true, true);
@@ -1082,6 +1084,18 @@
             return out;
         };
 
+        /**
+         * set the default scope selector
+         *
+         * @param  String  selector  CSS3 selector
+         * @return String
+         */
+        this.setScope = function setScope(selector) {
+            var scope = !(this.options.scope instanceof HTMLElement) ? this.getCssSelector(this.options.scope) : "";
+            this.options.scope = (selector !== "") ? this.findOne(selector) : document;
+            return scope;
+        };
+
         /**
          * Checks if any element matching a given selector is visible in remote page.
          *
